@@ -1,6 +1,6 @@
 /*
  * main.cc
- * Copyright (C) Martin Singer 2009-2011 <m_power3@users.sourceforge.net>
+ * Copyright (C) Martin Singer 2009-2013 <m_power3@users.sourceforge.net>
  * 
  * pdfchain is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,16 +17,35 @@
  */
 
 #include "pdfchain.h"
-#include "constants.h"
+#include "constant.h"
 #include "window_main.h"
 
 
+/*
 int
-main (int argc, char *argv[])
+main(
+	int argc ,
+	char *argv[] )
+{
+	Glib::RefPtr<Gtk::Application>
+		app = Gtk::Application::create( argc , argv , "pdfchain.sourceforge.net" );
+
+	cWindow_Main mWindow_Main;
+
+	return app->run( mWindow_Main );
+}
+*/
+
+int
+main (
+	int argc ,
+	char *argv[] )
 {
 	Gtk::Main kit( argc , argv );
 	
-	cWindow_Main* pWindow_Main = NULL;
+	cWindow_Main
+		*pWindow_Main = NULL;
+		
 	pWindow_Main = new cWindow_Main();
 	
 	if ( pWindow_Main ) {
